==> haskell-wreq-0.5.3.2-30-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wreq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wreq
version: 0.5.3.2
id: wreq-0.5.3.2-IFJItuiVWD6Cz4xNappbEe
key: wreq-0.5.3.2-IFJItuiVWD6Cz4xNappbEe
license: BSD-3-Clause
copyright: 2014 Bryan O'\''Sullivan
maintainer: bos@serpentine.com
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: http://www.serpentine.com/wreq
synopsis: An easy-to-use HTTP client library.
description:
    .
    A web client library that is designed for ease of use.
    .
    Tutorial: <http://www.serpentine.com/wreq/tutorial.html>
    .
    Features include:
    .
    * Simple but powerful `lens`-based API
    .
    * A solid test suite, and built on reliable libraries like
    http-client and lens
    .
    * Session handling includes connection keep-alive and pooling, and
    cookie persistence
    .
    * Automatic response body decompression
    .
    * Powerful multipart form and file upload handling
    .
    * Support for JSON requests and responses, including navigation of
    schema-less responses
    .
    * Basic and OAuth2 bearer authentication
    .
    * Early TLS support via the tls package
category: Web
abi: 5c962d38c90ebb3cb61900b12680e4e6
exposed: True
exposed-modules:
    Network.Wreq Network.Wreq.Cache Network.Wreq.Cache.Store
    Network.Wreq.Lens Network.Wreq.Session Network.Wreq.Types
hidden-modules: Network.Wreq.Internal Network.Wreq.Internal.AWS
                Network.Wreq.Internal.Lens Network.Wreq.Internal.Link
                Network.Wreq.Internal.OAuth1 Network.Wreq.Internal.Types
                Network.Wreq.Lens.Machinery Network.Wreq.Lens.TH Paths_wreq
import-dirs: /usr/lib/ghc-8.6.5/site-local/wreq-0.5.3.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/wreq-0.5.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/wreq-0.5.3.2
hs-libraries: HSwreq-0.5.3.2-IFJItuiVWD6Cz4xNappbEe
depends:
    aeson-1.4.3.0-AyEaiR0tyNR44JmKj60DSr
    attoparsec-0.13.2.2-3nUJVHBWBICGFmP4JcM3ay
    authenticate-oauth-1.6-K96OWo4TddIbxFl1jvoFI base-4.12.0.0
    base16-bytestring-0.1.1.6-17atVnUhDnM13pAkKbwL6I
    bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu containers-0.6.0.1
    cryptonite-0.25-DtJYWQJTat6yrCxAz9OOT
    exceptions-0.10.1-7EeRXpdm0c5D9yRsXefkxH ghc-prim-0.5.3
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    http-client-0.6.4-DCmpgbT5KA3LBdEx9Lt28S
    http-client-tls-0.3.5.3-59gffMozZgrJS4tvjSII2O
    http-types-0.12.3-FkUAYjCWW0WBZI2lM6bGTd
    lens-4.17-4Ddy4vxZdXoFxB1RvbUywU
    lens-aeson-1.0.2-51dITgRIyQOHhwEGCyDiKm
    memory-0.14.18-IbWiQctDwmh73RXfnLR7k6
    mime-types-0.1.0.9-2hmZJ5CmRudCuwA0xwTABk
    psqueues-0.2.7.1-KK5603rYUYa6x1F4YO1Gd3 template-haskell-2.14.0.0
    text-1.2.3.1 time-1.8.0.2
    time-locale-compat-0.1.1.5-4Kz46WDKPmGDmYVdO1w5q7
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
haddock-interfaces: /usr/share/doc/haskell-wreq/html/wreq.haddock
haddock-html: /usr/share/doc/haskell-wreq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wreq-0.5.3.2-33-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wreq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wreq
version: 0.5.3.2
id: wreq-0.5.3.2-JreDBg2y0LOL0VLojhLFmM
key: wreq-0.5.3.2-JreDBg2y0LOL0VLojhLFmM
license: BSD-3-Clause
copyright: 2014 Bryan O'\''Sullivan
maintainer: bos@serpentine.com
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: http://www.serpentine.com/wreq
synopsis: An easy-to-use HTTP client library.
description:
    .
    A web client library that is designed for ease of use.
    .
    Tutorial: <http://www.serpentine.com/wreq/tutorial.html>
    .
    Features include:
    .
    * Simple but powerful `lens`-based API
    .
    * A solid test suite, and built on reliable libraries like
    http-client and lens
    .
    * Session handling includes connection keep-alive and pooling, and
    cookie persistence
    .
    * Automatic response body decompression
    .
    * Powerful multipart form and file upload handling
    .
    * Support for JSON requests and responses, including navigation of
    schema-less responses
    .
    * Basic and OAuth2 bearer authentication
    .
    * Early TLS support via the tls package
category: Web
abi: c30e92752a31c901edbfa284aee7031c
exposed: True
exposed-modules:
    Network.Wreq Network.Wreq.Cache Network.Wreq.Cache.Store
    Network.Wreq.Lens Network.Wreq.Session Network.Wreq.Types
hidden-modules: Network.Wreq.Internal Network.Wreq.Internal.AWS
                Network.Wreq.Internal.Lens Network.Wreq.Internal.Link
                Network.Wreq.Internal.OAuth1 Network.Wreq.Internal.Types
                Network.Wreq.Lens.Machinery Network.Wreq.Lens.TH Paths_wreq
import-dirs: /usr/lib/ghc-8.6.5/site-local/wreq-0.5.3.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/wreq-0.5.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/wreq-0.5.3.2
hs-libraries: HSwreq-0.5.3.2-JreDBg2y0LOL0VLojhLFmM
depends:
    aeson-1.4.3.0-2f2DWYxbnUnFm9iFQHaKmb
    attoparsec-0.13.2.2-1slbQhZI8n0L2sAfK4cuOg
    authenticate-oauth-1.6-4J2iRcYsGef947F8M9aPt9 base-4.12.0.0
    base16-bytestring-0.1.1.6-17atVnUhDnM13pAkKbwL6I
    bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu containers-0.6.0.1
    cryptonite-0.25-DtJYWQJTat6yrCxAz9OOT
    exceptions-0.10.1-7EeRXpdm0c5D9yRsXefkxH ghc-prim-0.5.3
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    http-client-0.6.4-Cv7r4OJjM9k1hDatz0YNuk
    http-client-tls-0.3.5.3-FGEtAJdllnfFFv117grufi
    http-types-0.12.3-9p0mDzXduAV3s3QD76BvaS
    lens-4.17-4rCDtg2DCdcDxZQ0b6ZtZB
    lens-aeson-1.0.2-Cl3rFz5Pv4kA7QoOyh4StA
    memory-0.14.18-IbWiQctDwmh73RXfnLR7k6
    mime-types-0.1.0.9-2hmZJ5CmRudCuwA0xwTABk
    psqueues-0.2.7.1-KK5603rYUYa6x1F4YO1Gd3 template-haskell-2.14.0.0
    text-1.2.3.1 time-1.8.0.2
    time-locale-compat-0.1.1.5-4Kz46WDKPmGDmYVdO1w5q7
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
haddock-interfaces: /usr/share/doc/haskell-wreq/html/wreq.haddock
haddock-html: /usr/share/doc/haskell-wreq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
